API documentation
=================

The following documentation is based on the source code of version |release| of
the `executor` package. The following modules are available:

.. contents::
   :local:

The :mod:`executor` module
--------------------------

.. automodule:: executor
   :members:

The :mod:`executor.chroot` module
---------------------------------

.. automodule:: executor.chroot
   :members:

The :mod:`executor.cli` module
------------------------------

.. automodule:: executor.cli
   :members:

The :mod:`executor.concurrent` module
-------------------------------------

.. automodule:: executor.concurrent
   :members:

The :mod:`executor.contexts` module
-----------------------------------

.. automodule:: executor.contexts
   :members:

The :mod:`executor.process` module
----------------------------------

.. automodule:: executor.process
   :members:

The :mod:`executor.schroot` module
----------------------------------

.. automodule:: executor.schroot
   :members:

The :mod:`executor.ssh.client` module
-------------------------------------

.. automodule:: executor.ssh.client
   :members:

The :mod:`executor.ssh.server` module
-------------------------------------

.. automodule:: executor.ssh.server
   :members:

The :mod:`executor.tcp` module
------------------------------

.. automodule:: executor.tcp
   :members:
